@@ -18,6 +18,10 @@ class Pypackager(object):
         creator = PackageCreator(settings=self.settings)
         creator.create(package_name, destination)
 
+    def installed(self, *args):
+        channel = PackagerChannel(settings=self.settings)
+        channel.installed()
+
     def list(self, *args):
         channel = PackagerChannel(settings=self.settings)
         channel.list()
@@ -26,9 +30,9 @@ class Pypackager(object):
         channel = PackagerChannel(settings=self.settings)
         channel.search(text)
 
-    def download(self, package_name, *args):
+    def add(self, package_name, *args):
         channel = PackagerChannel(settings=self.settings)
-        channel.download(package_name)
+        channel.add(package_name, *args)
 
     def remove(self, package_name, *args):
         channel = PackagerChannel(settings=self.settings)
