@@ -21,19 +21,19 @@ def clean_dict(a_dict):
             continue
 
         if isinstance(v, dict):
-            ret[k] = clean_dict(v)
+            ret[k] = clean_dict(v).copy()
             continue
 
         ret[k] = v
 
-    for k, v in ret.items():
+    for k, v in ret.copy().items():
         if v == {}:
             del ret[k]
     return ret
 
 
 def recursive_update(d, u):
-    for k, v in u.iteritems():
+    for k, v in u.items():
         if isinstance(v, collections.Mapping):
             r = recursive_update(d.get(k, {}), v)
             d[k] = r
